Learn R Programming

pipr (version 1.4.0)

pip_is_transient: pip_is_transient

Description

Helper function to determine if an error is due to the number of requests going over the rate limit

Usage

pip_is_transient(resp)

Value

logical

Arguments

resp

A httr response